preprocessing: preprocessing: filtering step on genes/cells

View source: R/preprocessing.R

preprocessingR Documentation

preprocessing: filtering step on genes/cells

Description

preprocessing: filtering step on genes/cells

Usage

preprocessing(
  mat,
  meta,
  subject_var,
  group_var,
  sub_cell_filtering,
  gene_sub_filtering,
  gene_cell_filtering,
  ncell_filtering
)

Arguments

mat

Count matrix

meta

Data frame including information for cells

subject_var

The name of subject information in meta

group_var

The name of group/disease information for DE analysis in meta

sub_cell_filtering

Filtering on cells within each subject

gene_sub_filtering

Filtering on genes based on expression in each subject

gene_cell_filtering

Filtering on genes based on expression across all cells

ncell_filtering

Filtering on cells based on the number of genes expressed

Value

A list of processed count matrix and data frame


yl883/iDESC documentation built on Aug. 2, 2022, 1:21 a.m.