View source: R/preprocessing.R
| preprocessing | R Documentation |
preprocessing: filtering step on genes/cells
preprocessing( mat, meta, subject_var, group_var, sub_cell_filtering, gene_sub_filtering, gene_cell_filtering, ncell_filtering )
mat |
Count matrix |
meta |
Data frame including information for cells |
subject_var |
The name of subject information in meta |
group_var |
The name of group/disease information for DE analysis in meta |
sub_cell_filtering |
Filtering on cells within each subject |
gene_sub_filtering |
Filtering on genes based on expression in each subject |
gene_cell_filtering |
Filtering on genes based on expression across all cells |
ncell_filtering |
Filtering on cells based on the number of genes expressed |
A list of processed count matrix and data frame
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.